Receptor
==============

[![Documentation](https://readthedocs.org/projects/receptor/badge/?version=stable)](https://receptor.readthedocs.io/en/latest/)
[![Receptor Testing](https://github.com/project-receptor/receptor/workflows/Receptor%20Testing/badge.svg)](https://github.com/project-receptor/receptor/actions?query=workflow%3A%22Receptor+Testing%22)


For the latest documentation see: [https://receptor.readthedocs.io](https://receptor.readthedocs.io/en/latest/)

Get Involved
============

* We use [GitHub issues](https://github.com/project-receptor/receptor/issues) to track bug report and feature ideas...
* Want to contribute, check out our [guide](CONTRIBUTING.md)
* Join us in the `#receptor` channel on Freenode IRC
